dot-create_design_matrix: Create the Design Matrix for a Simulation

.create_design_matrixR Documentation

Create the Design Matrix for a Simulation

Description

An internal helper function that takes the design specification and an lme4-style formula to generate a design matrix representing the structure of the experimental design.

Usage

.create_design_matrix(design, formula = NULL)

Arguments

design

A PowRPriori_design object from define_design().

formula

The lme4-style model formula.

Value

A tibble (data frame) with predictor variables.


PowRPriori documentation built on May 12, 2026, 5:06 p.m.