| .plot_data | R Documentation |
An internal helper function containing the logic to "intelligently" create
plots from simulated data. It automatically chooses between spaghetti plots and jitter/point-range plots depending on
the specified design and model family.It derives sensible defaults for plot aesthetics from the design,
if they are not supplied directly via the plot_sim_model function.
.plot_data(
data,
design,
formula,
family,
x_var,
group_var,
color_var,
facet_var,
n_data_points
)
data |
The data frame to plot. |
design |
The |
formula |
An lme4-style formula (e.g. |
family |
The model family. Defaults to |
x_var, group_var, color_var, facet_var |
Strings specifying variables for plot aesthetics. |
n_data_points |
The maximum number of trajectories in spaghetti plots. |
A ggplot object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.