| .create_design_matrix | R Documentation |
An internal helper function that takes the design specification and an lme4-style formula to generate a design matrix representing the structure of the experimental design.
.create_design_matrix(design, formula = NULL)
design |
A |
formula |
The lme4-style model formula. |
A tibble (data frame) with predictor variables.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.