| .simulate_outcome | R Documentation |
An internal helper function that takes a complete design matrix and simulates the dependent variable based on the specified fixed and random effects.
.simulate_outcome(
design_df,
formula,
fixed_effects,
sds_random,
family = "gaussian"
)
design_df |
The data frame from |
formula |
The model formula. |
fixed_effects |
A list of the fixed effects coefficients. |
sds_random |
A list of the random effects' standard deviations and correlations. |
family |
A string indicating the model family. |
The input design_df with an added column for the outcome variable.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.