| get_fixed_effects_structure | R Documentation |
Analyzes a model formula and a design object to generate a template for the
fixed_effects parameter. This is a helper function designed to prevent
typos and ensure all necessary coefficients are specified. By default, this function prints a copy-paste-able code snippet
to the console, where the user only needs to fill in placeholders (...) for the values.
get_fixed_effects_structure(formula, design)
formula |
An lme4-style model formula (e.g. |
design |
A |
Invisibly returns a named list with placeholders, which can be used
as a template for the fixed_effects argument in power_sim().
design <- define_design(
sample_size = list(subject = 20),
between = list(group = c("Control", "Treatment")),
within = list(time = c("pre", "post"))
)
get_fixed_effects_structure(y ~ group * time, design)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.